@@ -1,6 +1,8 @@
 import unittest
 
 from explainaboard import get_task_categories
+from explainaboard.loaders.loader_registry import get_supported_file_types_for_loader
+from explainaboard.processors.processor_registry import get_metric_list_for_processor
 
 
 class TestTasks(unittest.TestCase):
@@ -17,10 +19,12 @@ class TestTasks(unittest.TestCase):
             self.assertIsNotNone(task_category.description)
             self.assertIsNotNone(task_category.name)
             for task in task_category.tasks:
+                supported_metrics = get_metric_list_for_processor(task.name)
+                supported_formats = get_supported_file_types_for_loader(task.name)
                 self.assertEqual(
-                    len(task.supported_metrics),
-                    len(set(task.supported_metrics)),
-                    f"duplicate metrics in {task.name}",
+                    len(supported_metrics),
+                    len(set([x.name for x in supported_metrics])),
+                    f"duplicate metric names in {task.name}",
                 )
-                self.assertGreater(len(task.supported_formats.custom_dataset), 0)
-                self.assertGreater(len(task.supported_formats.system_output), 0)
+                self.assertGreater(len(supported_formats.custom_dataset), 0)
+                self.assertGreater(len(supported_formats.system_output), 0)
