@@ -34,9 +34,24 @@ def get_default_tokenizer(task_type: TaskType, lang: str | None) -> Tokenizer:
         return SingleSpaceTokenizer()
 
 
+class TokenSeq:
+    def __init__(self, strs: list[str] = None, positions: list[int] = None):
+        self.strs: list[str] = strs or []
+        self.positions: list[int] = positions or []
+
+    def __getitem__(self, item) -> str:
+        return self.strs.__getitem__(item)
+
+    def __len__(self) -> int:
+        return self.strs.__len__()
+
+    def __iter__(self):
+        return self.strs.__iter__()
+
+
 class Tokenizer:
     @abc.abstractmethod
-    def __call__(self, text: str) -> list[str]:
+    def __call__(self, text: str) -> TokenSeq:
         """
         Tokenize a string into a list of tokens
         :param text: The string to tokenize
@@ -67,6 +82,19 @@ class Tokenizer:
         thismodule = sys.modules[__name__]
         return getattr(thismodule, cls_name)(**new_v)
 
+    @staticmethod
+    def find_spans(orig_str: str, str_list: list[str]) -> TokenSeq:
+        start = 0
+        ret = TokenSeq()
+        for x in str_list:
+            next_start = orig_str.find(x, start)
+            if next_start == -1:
+                raise ValueError(f'could not "{orig_str}".find({x}, {start})')
+            ret.strs.append(x)
+            ret.positions.append(next_start)
+            start = next_start
+        return ret
+
 
 class SingleSpaceTokenizer(Tokenizer):
     """
@@ -74,8 +102,14 @@ class SingleSpaceTokenizer(Tokenizer):
     """
 
     @lru_cache(maxsize=20)
-    def __call__(self, text: str) -> list[str]:
-        return text.split(' ')
+    def __call__(self, text: str) -> TokenSeq:
+        ret = TokenSeq()
+        start = 0
+        for x in text.split(' '):
+            ret.strs.append(x)
+            ret.positions.append(start)
+            start = start + len(x) + 1
+        return ret
 
     def detokenize(self, tokens: list[str]) -> str:
         return ' '.join(tokens)
@@ -89,8 +123,6 @@ class TokenizerConala(BaseTokenizer):
     A SacreBLEU style tokenizer of the tokenizer that we use for BLEU score over Python
     code, as used by the CoNaLa corpus.
     Originally from Wang Ling et al., Latent Predictor Networks for Code Generation
-    :param text: string containing a code snippet
-    :return: list of code tokens
     """
 
     def __call__(self, text: str) -> str:
@@ -110,27 +142,39 @@ class TokenizerConala(BaseTokenizer):
         return text
 
 
+def _no_normalizer(text: str) -> str:
+    return text
+
+
+def _conala_normalizer(text: str) -> str:
+    text = text.replace('"', '`')
+    text = text.replace('\'', '`')
+    return text
+
+
 class SacreBleuTokenizer(Tokenizer):
     """
     Split a string based on the strategy in SacreBLEU
     """
 
     def __init__(self, variety: str = 'intl'):
+        self.normalizer = _no_normalizer
         self.variety = variety
         if variety == 'intl':
-            self.tokenizer = TokenizerV14International()
+            self.tokenizer: BaseTokenizer = TokenizerV14International()
         elif variety == 'zh':
             self.tokenizer = TokenizerZh()
         elif variety == 'ja-mecab':
             self.tokenizer = TokenizerJaMecab()
         elif variety == 'conala':
             self.tokenizer = TokenizerConala()
+            self.normalizer = _conala_normalizer
         else:
             raise ValueError(f'Illegal variety of SacreBleuTokenizer: {variety}')
 
     @lru_cache(maxsize=20)
-    def __call__(self, text: str) -> list[str]:
-        return self.tokenizer(text).split(' ')
+    def __call__(self, text: str) -> TokenSeq:
+        return self.find_spans(self.normalizer(text), self.tokenizer(text).split(' '))
 
     def detokenize(self, tokens: list[str]) -> str:
         raise NotImplementedError
@@ -149,9 +193,9 @@ class MLQAMixTokenizer(Tokenizer):
     }.union(string.punctuation)
 
     @lru_cache(maxsize=20)
-    def __call__(self, text: str) -> list[str]:
+    def __call__(self, text: str) -> TokenSeq:
 
-        segs_out = []
+        segs_out: list[str] = []
         temp_str = ""
         for char in text:
             if re.search(r'[\u4e00-\u9fa5]', char) or char in self.PUNCT:
@@ -167,7 +211,7 @@ class MLQAMixTokenizer(Tokenizer):
             ss = self.ss_tokenizer(temp_str)
             segs_out.extend(ss)
 
-        return segs_out
+        return self.find_spans(text, segs_out)
 
     def detokenize(self, tokens: list[str]) -> str:
         raise NotImplementedError
